package proxy.command;

import proxy.Proxy;
import proxy.network.ProxyHandler;
import proxy.util.Formatter;
import proxy.util.User;

public class CommandRegister extends Command {
	public String getName() {
		return "register";
	}
	
	public String getHelp() {
		return "Registers a new user or lists users";
	}
	
	public String getArgs() {
		return "<username> <password>";
	}

	public int getRedactedLogArg(int args) {
		return 1;
	}

	public void run(Proxy proxy, ProxyHandler player, String[] args) {
		if(args.length == 0) {
			int cnt = proxy.getUsers().size();
			for(User user : proxy.getUsers()) {
				sendMessage(player, (user.isAdmin() ? Formatter.GOLD : Formatter.GREEN) + user.getUsername());
			}
			sendMessage(player, (cnt == 0 ? Formatter.GRAY + "No users" : Formatter.DARK_GREEN + (cnt == 1 ? "1 user" : "%d users")) + " on this proxy", cnt);
			return;
		}
		if(args.length < 2)
			throw new RunException("Please provide a username and a password");
		if(!Formatter.isValidUser(args[0]))
			throw new RunException("'%s' is not a valid username", args[0]);
		else if(args[0].length() < 3)
			throw new RunException("Username too short, length must be between 3-16 characters");
		else if(args[0].length() > 16)
			throw new RunException("Username too long, length must be between 3-16 characters");
		User user = proxy.getUser(args[0]);
		if(user != null)
			throw new RunException("%s is already registered", user.getUsername());
		if(args[1].isEmpty() || args[1].length() < proxy.getMinimumPasswordLength())
			throw new RunException("Password too short, length must be between %d-32 characters", proxy.getMinimumPasswordLength());
		else if(args[1].length() > 32)
			throw new RunException("Password too long, length must be between %d-32 characters", proxy.getMinimumPasswordLength());
		proxy.setUser(User.createUser(args[0], args[1]));
		sendInfo(player, "%s was successfully registered", args[0]);
	}
}
