package proxy.nbt;

import java.io.DataInput;
import java.io.DataOutput;
import java.io.IOException;
import java.util.Map;
import com.google.common.collect.Maps;

public class NbtCompound extends Nbt {
	private Map<String, Nbt> tags = Maps.newHashMap();

	void write(DataOutput output) throws IOException {
		for(String key : this.tags.keySet()) {
			Nbt tag = this.tags.get(key);
			output.writeByte(tag.getId());
			if(tag.getId() != 0) {
				output.writeUTF(key);
				tag.write(output);
			}
		}
		output.writeByte(0);
	}

	void read(DataInput input, int depth, Tracker tracker) throws IOException {
		tracker.read(384L);
		if(depth > 512)
			throw new RuntimeException("Tried to read tag tree deeper than 512");
		this.tags.clear();
		byte type;
		while((type = input.readByte()) != 0) {
			String key = input.readUTF();
			tracker.read((long)(224 + 16 * key.length()));
			Nbt tag = Nbt.createTag(type);
			tag.read(input, depth + 1, tracker);
			if(this.tags.put(key, tag) != null)
				tracker.read(288L);
		}
	}

	byte getId() {
		return (byte)10;
	}

	public String getString(String key) {
		Nbt tag = this.tags.get(key);
		return tag instanceof NbtString ? ((NbtString)tag).getData() : null;
	}

	public int getStringListLength(String key) {
		Nbt tag = this.tags.get(key);
		return tag instanceof NbtList ? ((NbtList)tag).getStringListLength() : -1;
	}

	public static NbtCompound readTag(DataInput input) throws IOException {
		if(input.readByte() != 10)
			throw new IOException("Root is not a compound");
		input.readUTF();
		NbtCompound tag = new NbtCompound();
		tag.read(input, 0, new Tracker());
		return tag;
	}

	public static void writeTag(NbtCompound tag, DataOutput output) throws IOException {
		output.writeByte(tag.getId());
		output.writeUTF("");
		tag.write(output);
	}
}
