package proxy.network;

import proxy.Proxy;
import proxy.packet.H00PacketHandshake;
import proxy.packet.R00PacketDisconnect;

public class HandshakeHandler implements Handler {
	private final Proxy proxy;
	private final Connection connection;

	public HandshakeHandler(Proxy proxy, Connection connection) {
		this.proxy = proxy;
		this.connection = connection;
	}

	public void processHandshake(H00PacketHandshake packet) {
		switch(packet.getRequestedState()) {
			case LOGIN:
				this.connection.setConnectionState(Protocol.LOGIN);
	
				if(packet.getProtocolVersion() > 47) {
					String text = "Outdated server! I\'m still on 1.8.9";
					this.connection.sendPacket(new R00PacketDisconnect(text));
					this.connection.closeChannel(text);
				}
				else if(packet.getProtocolVersion() < 47) {
					String text = "Outdated client! Please use 1.8.9";
					this.connection.sendPacket(new R00PacketDisconnect(text));
					this.connection.closeChannel(text);
				}
				else {
					this.connection.setNetHandler(new LoginHandler(this.proxy, this.connection));
				}
	
				break;
	
			case STATUS:
				this.connection.setConnectionState(Protocol.STATUS);
				this.connection.setNetHandler(new StatusHandler(this.proxy, this.connection));
				break;
	
			default:
				throw new UnsupportedOperationException("Invalid intention " + packet.getRequestedState());
		}
	}

	public void onDisconnect(Connection connection, String reason) {
	}
}
