package proxy.packet;

import java.io.IOException;

import proxy.network.ProxyHandler;
import proxy.network.Packet;
import proxy.network.PacketBuffer;
import proxy.util.Vec3;

public class C07PacketPlayerDigging implements Packet<ProxyHandler>
{
    private Vec3 position;
    private byte facing;
    private C07PacketPlayerDigging.Action status;

    /**
     * Reads the raw packet data from the data stream.
     */
    public void readPacketData(PacketBuffer buf) throws IOException
    {
        this.status = (C07PacketPlayerDigging.Action)buf.readEnumValue(C07PacketPlayerDigging.Action.class);
        this.position = buf.readVector();
        this.facing = (byte)buf.readUnsignedByte();
    }

    /**
     * Writes the raw packet data to the data stream.
     */
    public void writePacketData(PacketBuffer buf) throws IOException
    {
        buf.writeEnumValue(this.status);
        buf.writeVector(this.position);
        buf.writeByte(this.facing);
    }

    /**
     * Passes this Packet on to the NetHandler for processing.
     */
    public void processPacket(ProxyHandler handler)
    {
        handler.processPlayerDigging(this);
    }

    public static enum Action
    {
        START_DESTROY_BLOCK,
        ABORT_DESTROY_BLOCK,
        STOP_DESTROY_BLOCK,
        DROP_ALL_ITEMS,
        DROP_ITEM,
        RELEASE_USE_ITEM;
    }
}
