package proxy.packet;

import java.io.IOException;
import java.util.UUID;

import proxy.network.ProxyHandler.ProxyLoginHandler;
import proxy.network.Packet;
import proxy.network.PacketBuffer;

public class R02PacketLoginSuccess implements Packet<ProxyLoginHandler>
{
	private UUID id;
    private String name;

    public R02PacketLoginSuccess()
    {
    }

    public R02PacketLoginSuccess(UUID id, String name)
    {
        this.id = id;
        this.name = name;
    }

    /**
     * Reads the raw packet data from the data stream.
     */
    public void readPacketData(PacketBuffer buf) throws IOException
    {
        String s = buf.readStringFromBuffer(36);
        this.name = buf.readStringFromBuffer(16);
        this.id = UUID.fromString(s);
    }

    /**
     * Writes the raw packet data to the data stream.
     */
    public void writePacketData(PacketBuffer buf) throws IOException
    {
        buf.writeString(this.id == null ? "" : this.id.toString());
        buf.writeString(this.name);
    }

    /**
     * Passes this Packet on to the NetHandler for processing.
     */
    public void processPacket(ProxyLoginHandler handler)
    {
        handler.handleLoginSuccess(this);
    }

    public UUID getId()
    {
        return this.id;
    }

    public String getName()
    {
        return this.name;
    }
}
